package cn.com.qmth.stmms.ms.collect.util;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.HashSet;

import javax.imageio.ImageIO;

import org.apache.commons.codec.digest.DigestUtils;

import cn.com.qmth.stmms.ms.commons.config.SystemConfig;
import cn.com.qmth.stmms.ms.commons.utils.image.ImageCompression;
import cn.com.qmth.stmms.ms.core.domain.Paper;
import cn.com.qmth.stmms.ms.core.repository.PaperRepo;

public class RotateTask  implements Runnable {
	
    private Paper paper;
    private int degree;
    private PaperRepo paperRepo;
    private SystemConfig systemConfig;
    private HashSet<String> papers;

    public RotateTask(Paper paper,int degree, PaperRepo paperRepo, SystemConfig systemConfig, HashSet<String> papers) {
    	this.paper = paper;
        this.degree = degree;
        this.paperRepo = paperRepo;
        this.systemConfig = systemConfig;
        this.papers = papers;
    }

	@Override
	public void run() {
		long start = System.currentTimeMillis();
		 Path thumbPath = Paths.get(systemConfig.getThumbDir(),String.valueOf(paper.getWorkId()),paper.getSubject().toString(),paper.getAreaCode(),paper.getExamNumber() + ".jpg");
	     Path imagePath = Paths.get(systemConfig.getImageDir(),String.valueOf(paper.getWorkId()),paper.getSubject().toString(),paper.getAreaCode(),paper.getExamNumber() + ".jpg");
		try {
			File thumbFile = thumbPath.toFile();
			if (thumbFile.exists()) {
				InputStream is = new FileInputStream(thumbFile);
				BufferedImage image = ImageIO.read(is);
				ImageCompression.rotate(thumbFile, thumbFile, degree);
				is.close();
			}
			File imageFile = imagePath.toFile();
			if (imageFile.exists()) {
				InputStream is = new FileInputStream(imageFile);
				BufferedImage image = ImageIO.read(is);
				ImageCompression.rotate(imageFile, imageFile, degree);
				is.close();
			}
	        FileInputStream in = new FileInputStream(imageFile);
	        String sliceMD5 = DigestUtils.md5Hex(in);
			paper.setSliceMD5(sliceMD5);
			paperRepo.save(paper);
			papers.remove(paper.getExamNumber());
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException ioe) {
			ioe.printStackTrace();
		}
		long end = System.currentTimeMillis();
		System.out.println("完成任务，耗时：" + (end - start) + "毫秒");
	}
}
